class RunnerFilter(object):
    framework = 'all'
    checks = []

    def __init__(self, framework='all', checks=None):
        if checks is None:
            checks = []
        if isinstance(checks,str):
            self.checks = checks.split(",")
        self.framework = framework
        self.checks = checks



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class SQSQueueEncryption(BaseResourceCheck):
    def __init__(self):
        name = "Ensure all data stored in the SQS queue  is encrypted"
        id = "CKV_AWS_27"
        supported_resources = ['aws_sqs_queue']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for encryption configuration at aws_sqs_queue:
            https://www.terraform.io/docs/providers/aws/r/sqs_queue.html
        :param conf: aws_s3_bucket configuration
        :return: <CheckResult>
        """
        if 'kms_master_key_id' in conf.keys():
            if conf['kms_master_key_id']:
                return CheckResult.PASSED
        return CheckResult.FAILED


check = SQSQueueEncryption()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class GKEPodSecurityPolicyEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure PodSecurityPolicy controller is enabled on the Kubernetes Engine Clusters"
        id = "CKV_GCP_24"
        supported_resources = ['google_container_cluster']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "pod_security_policy_config/[0]/enabled"


check = GKEPodSecurityPolicyEnabled()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class S3PublicACLWrite(BaseResourceCheck):
    def __init__(self):
        name = "S3 Bucket has an ACL defined which allows public WRITE access."
        id = "CKV_AWS_57"
        supported_resources = ['aws_s3_bucket']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for ACL configuration at aws_s3_bucket:
            https://www.terraform.io/docs/providers/aws/r/s3_bucket.html
        :param conf: aws_s3_bucket configuration
        :return: <CheckResult>
        """
        if 'acl' in conf.keys():
            acl_block = conf['acl']
            if acl_block[0] == "public-read-write":
                return CheckResult.FAILED
        return CheckResult.PASSED


check = S3PublicACLWrite()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class S3MFADelete(BaseResourceCheck):


    def __init__(self):
        name = "Ensure S3 bucket has MFA delete enabled"
        id = "CKV_AWS_52"
        supported_resources = ['aws_s3_bucket']
        categories = [CheckCategories.BACKUP_AND_RECOVERY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):

        if 'versioning' in conf.keys():
            versioning_block = conf['versioning']
            for block in versioning_block:
                if type(block) is not dict:
                    return CheckResult.PASSED
                if 'mfa_delete' in block.keys():
                    if block['mfa_delete']:

                        return CheckResult.PASSED
        return CheckResult.FAILED

scanner = S3MFADelete()



import re

from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.terraform.checks.utils.consts import access_key_pattern, secret_key_pattern


class LambdaEnvironmentCredentials(BaseResourceCheck):

    def __init__(self):
        name = "Ensure no hard coded AWS access key and and secret key exists in lambda environment"
        id = "CKV_AWS_45"
        supported_resources = ['aws_lambda_function']
        categories = [CheckCategories.SECRETS]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'environment' in conf.keys():
            if isinstance(conf['environment'][0], dict):
                if 'variables' in conf['environment'][0]:
                    if not isinstance(conf['environment'][0]['variables'], list):
                        conf['environment'][0]['variables'] = [conf['environment'][0]['variables']]
                    if isinstance(conf['environment'][0]['variables'][0], dict):
                        # variables can be a string, which in this case it points to a variable
                        for values in list(conf['environment'][0]['variables'][0].values()):
                            if not isinstance(values, list):
                                values = [values]
                            for value in list(filter(lambda value: isinstance(value, str), values)):
                                    if re.match(access_key_pattern, value) or re.match(secret_key_pattern, value):
                                        return CheckResult.FAILED
        return CheckResult.PASSED


check = LambdaEnvironmentCredentials()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class S3Encryption(BaseResourceCheck):
    def __init__(self):
        name = "Ensure all data stored in the S3 bucket is securely encrypted at rest"
        id = "CKV_AWS_19"
        supported_resources = ['aws_s3_bucket']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for encryption configuration at aws_s3_bucket:
            https://www.terraform.io/docs/providers/aws/r/s3_bucket.html
        :param conf: aws_s3_bucket configuration
        :return: <CheckResult>
        """
        if 'server_side_encryption_configuration' in conf.keys():
            sse_block = conf['server_side_encryption_configuration']
            if type(sse_block[0]) is not dict:
                # all non-dict sse_blocks will return as PASSED
                return CheckResult.PASSED
            if 'rule' in sse_block[0].keys():
                rule_block = sse_block[0]['rule']
                if isinstance(rule_block, dict):
                    rule_block = [rule_block]
                if 'apply_server_side_encryption_by_default' in rule_block[0].keys():
                    encryption_block = rule_block[0]['apply_server_side_encryption_by_default']
                    if isinstance(encryption_block, dict):
                        encryption_block = [encryption_block]
                    if 'sse_algorithm' in encryption_block[0].keys():
                        return CheckResult.PASSED
        return CheckResult.FAILED


check = S3Encryption()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class KinesisStreamEncryptionType(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Kinesis Stream is securely encrypted"
        id = "CKV_AWS_43"
        supported_resources = ['aws_kinesis_stream']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for encryption_type to be KMS  at aws_kinesis_stream:
            https://www.terraform.io/docs/providers/aws/r/kinesis_stream.html
        :param conf:  aws_kinesis_stream configuration
        :return: <CheckResult>
        """
        if "encryption_type" in conf.keys():
            if (conf["encryption_type"][0] == "KMS"):
                return CheckResult.PASSED
            else:
                return CheckResult.FAILED
        else:
            return CheckResult.FAILED



check = KinesisStreamEncryptionType()

